componenttools.partition_components_by_durations_exactly
========================================================

.. autofunction:: abjad.tools.componenttools.partition_components_by_durations_exactly.partition_components_by_durations_exactly
   :noindex:
